@@ -51,7 +51,7 @@ import importlib
 description = "A really simple-to-use HTTP-server"
 address = ("localhost", 8080)
 name = "Serverly"
-version = "0.2.8"
+version = "0.2.10"
 logger = Logger("serverly.log", "serverly", False, False)
 logger.header(True, True, description, fileloghelper_version=True,
               program_version="serverly v" + version)
@@ -311,10 +311,7 @@ class Sitemap:
     def get_func_or_site_response(self, site, request: Request):
         response = Response()
         if isinstance(site, StaticSite):
-            text = site.get_content()
-            filetype = mimetypes.guess_type(site.file_path)
-            info = {"Content-type": filetype,
-                    "Content-Length": len(text)}
+            response = Response(body=site.get_content())
         elif callable(site):
             try:
                 content = site(request)
